==> haskell-wai-app-file-cgi-3.1.10-183-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-file-cgi
version:              3.1.10
visibility:           public
id:                   wai-app-file-cgi-3.1.10-HSBsF78T8IrCgTmQZfn8tT
key:                  wai-app-file-cgi-3.1.10-HSBsF78T8IrCgTmQZfn8tT
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  aba5ed6ffd1b3dcde31f77f0f348b9dc
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.10-HSBsF78T8IrCgTmQZfn8tT
depends:
    array-0.5.4.0 attoparsec-0.14.4-l6gpYVAuXa4krkAJlMwbn base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb containers-0.6.5.1
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp directory-1.3.6.2
    filepath-1.4.2.2 http-client-0.7.15-DQnyZx9lzoSgMdf26TxD3
    http-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
    http-date-0.0.11-9IwamcJwgdC2b1hbg6kbEw
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3 process-1.6.16.0
    sockaddr-0.0.1-1UXUGGeg7H39TGwfsdOLxY
    static-hash-0.0.2-55ZTA5p1wzp931nFQE8Lpv text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2 wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU
    wai-conduit-3.0.0.4-19wDqhhcjOrJ9WPE91Xhfn
    warp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-file-cgi-3.1.10-208-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-app-file-cgi
version:              3.1.10
visibility:           public
id:                   wai-app-file-cgi-3.1.10-FiJ5s4EqBpH4E4fY7IIbrz
key:                  wai-app-file-cgi-3.1.10-FiJ5s4EqBpH4E4fY7IIbrz
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  a7feea157f4824d2860e19362558fe30
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-app-file-cgi-3.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.10-FiJ5s4EqBpH4E4fY7IIbrz
depends:
    array-0.5.4.0 attoparsec-0.14.4-7zFXPvsAeTc17D9FbG47Bq
    base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh
    conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD containers-0.6.5.1
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp directory-1.3.6.2
    filepath-1.4.2.2 http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
    http-date-0.0.11-E2fwJvbT2lF8g6FW0xlnls
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ process-1.6.16.0
    sockaddr-0.0.1-68fImcSXVpr4VSvaheOGQc
    static-hash-0.0.2-4xayAXOMUjq9eRNoGj5uCV text-1.2.5.0
    transformers-0.5.6.2 unix-2.7.2.2 wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q
    wai-conduit-3.0.0.4-uEsZHfNZDi4OMmfx6kehI
    warp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
